netapp_ontap.models.performance_svm_nfs_metric_historical API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.performance_svm_nfs_metric_historical`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class PerformanceSvmNfsMetricHistoricalSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the PerformanceSvmNfsMetricHistorical object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the performance_svm_nfs_metric_historical.

  `timestamp: ImpreciseDateTime GET`

    The timestamp of the performance data.

    Example: 2017-01-25T11:20:13.000+0000

  `v3: PerformanceSvmNfsMetricHistoricalV3 GET`

    The NFSv3 operations

  `v4: PerformanceSvmNfsMetricHistoricalV4 GET`

    The NFSv4 operations

  `v41: PerformanceSvmNfsMetricHistoricalV41 GET`

    The NFSv4.1 operations